%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Returns inital guesses and boundaries for a Flash tank
% given the parameters and that the flash is in the vapor-only regime
% @input: par = parameters
% @output: w0 = Initial guesses, lb = lower boundaries, ub = upper
% boundaries
%******************************************************************

function [w0,lb,ub] = initialGuesses_gases(par)

% M_1 = w(1);           % Component 1 molar hold-up [kmol]
w0(1) = 0.5;
lb(1) = 0;
ub(1) = inf;
% M_2 = w(2);           % Component 2 molar hold-up [kmol]
w0(2) = 0.5;
lb(2) = 0;
ub(2) = inf;
% U = w(3);             % Internal energy [MJ]
w0(3) = -1;
lb(3) = -inf;
ub(3) = inf;
% F_V = w(4);           % Vapor flow rate [kmol/s]
w0(4) = par.F_in;
lb(4) = par.F_in;
ub(4) = par.F_in;
% F_L = w(5);           % Liquid flow rate [kmol/s]
w0(5) = 0;
lb(5) = 0;
ub(5) = 0;
% M_V = w(6);           % Vapor molar hold-up [kmol]
w0(6) = 0.1;
lb(6) = 0;
ub(6) = inf;
% P = w(7);             % Pressure [MPa]
w0(7) = 0.11;
lb(7) = 0;
ub(7) = inf;
% T = w(8);             % Temperature [kK]
w0(8) = par.T_in;
lb(8) = par.T_in;
ub(8) = par.T_in;
% V_L = w(9);           % Liquid volume [m^3]
w0(9) = 0;
lb(9) = 0;
ub(9) = 0;
% x_1 = w(10);          % Liquid mole fraction component 1
w0(10) = 0.5;
lb(10) = 0;
ub(10) = inf;
% x_2 = w(11);          % Liquid mole fraction component 2
w0(11) = 0.5;
lb(11) = 0;
ub(11) = inf;
% y_1 = w(12);          % Vapor mole fraction component 1
w0(12) = par.z(1);
lb(12) = par.z(1);
ub(12) = par.z(1);
% y_2 = w(13);          % Vapor mole fraction component 2
w0(13) = par.z(2);
lb(13) = par.z(2);
ub(13) = par.z(2);
% H = w(14);            % Enthalpy [MJ]
w0(14) = 1;
lb(14) = -inf;
ub(14) = inf;
% h_L = w(15);          % Liquid molar enthalpy [MJ/kmol]
w0(15) = par.h_in;
lb(15) = -inf;
ub(15) = inf;
% h_V = w(16);          % Vapor molar enthalpy [MJ/kmol]
w0(16) = par.h_in;
lb(16) = par.h_in;
ub(16) = par.h_in;
% V_V = w(17);          % Vapor volume [m^3]
w0(17) = par.V_T;
lb(17) = par.V_T;
ub(17) = par.V_T;
% rho_L = w(18);        % Liquid molar density [Mmol/m^3]
w0(18) = 0.5;
lb(18) = 0;
ub(18) = inf;
% M_L = w(19);          % Liquid molar hold-up [kmol]
w0(19) = 0;
lb(19) = 0;
ub(19) = 0;
% K_1 = w(20);          % Vapor-liquid equilibrium coefficient comp 1
w0(20) = 1;
lb(20) = 0;
ub(20) = inf;
% K_2 = w(21);          % Vapor-liquid equilibrium coefficient comp 2
w0(21) = 1;
lb(21) = 0;
ub(21) = inf;
% Ps_1 = w(22);         % Saturation Pressure component 1 [MPa]
w0(22) = 0.1;
lb(22) = 0;
ub(22) = inf;
% Ps_2 = w(23);         % Saturation Pressure component 1 [MPa]
w0(23) = 0.1;
lb(23) = 0;
ub(23) = inf;
w0 = w0';
end