%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Implicit Euler integrator for the counter current heat
% exchanger model. 
% @input: w0 = initial conditions, data = parameters, dt = time step,
% tspan = [t_start, t_end]
% @output: t_vec = time vector, w = System variables matrix, Q = heat
% transfer, F_in_2 = Inlet flow rate cold side, F_in = Flow Rate hot side,
% T_in_2 = Inlet temperature cold side
%******************************************************************

function [t_vec,w,Q,F_in_2,F_in,T_in_2] = implicitSolverFull_CC...
    (w0,data,dt,tspan)

%% Solver settings
options_fsolve = optimoptions(@fsolve,'Display','iter',...
     'MaxIterations',2e3,'MaxFunEvals',1e10,...
     'stepTolerance',1e-13,'FunctionTolerance',1e-13,...
     'specifyObjectiveGradient', true,...
     'OptimalityTolerance',1e-13, 'Algorithm','levenberg-marquardt');
%% Initial values and preallocating memory
t = tspan(1);
t_vec = tspan(1);
M = data.par.M;
w = zeros(length(w0),length(t));
w(:,1) = w0;
dynVar = [w0(1:2*M);w0(18*M+1:20*M)];
[~,~,Q(:,1),F_in_2(1),F_in(1),T_in_2(1)] =...
    HEX_CC_implicit(t,w0,data,dynVar,dt);

i = 1;
while t + dt <= tspan(2)
    i = i+1;                % Index counter
    t = t + dt;             % Next Time
    disp(t);
    t_vec = [t_vec t];      % Adding next time in time vector
    w0 = w(:,i-1);          % Initial guess equal to previous solution
    dynVar = [w(1:2*M,i-1);w(18*M+1:20*M,i-1)]; % Dynamic variable values
    w(:,i) = fsolve(@(w) HEX_CC_implicit...
        (t,w,data,dynVar,dt),w0,options_fsolve);    % Solving model
    [~,~,Q(:,i),F_in_2(i),F_in(i),T_in_2(i)] =...
        HEX_CC_implicit(t,w(:,i),data,dynVar,dt);   % Saving values  
end
end