%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Returns inital guesses and boundaries for a Flash tank
% given the parameters and that the flash is in the liquid-only regime
% @input: par = parameters
% @output: w0 = Initial guesses, lb = lower boundaries, ub = upper
% boundaries
%******************************************************************


function [w0,lb,ub] = initialGuesses_liquid(par)

% M_1 = w(1);           % Component molar hold-up [kmol]
w0(1) = 0.5;
lb(1) = 0;
ub(1) = inf;
% U = w(2);             % Internal energy [MJ]
w0(2) = -1;
lb(2) = -inf;
ub(2) = inf;
% F_V = w(3);           % Vapor flow rate [kmol/s]
w0(3) = 0;
lb(3) = 0;
ub(3) = 0;
% F_L = w(4);           % Liquid flow rate [kmol/s]
w0(4) = par.F_in;
lb(4) = par.F_in;
ub(4) = par.F_in;
% M_V = w(5);           % Vapor molar hold-up [kmol]
w0(5) = 0;
lb(5) = 0;
ub(5) = 0;
% P = w(6);             % Pressure [MPa]
w0(6) = 0.12;
lb(6) = 0.1;
ub(6) = inf;
% T = w(7);             % Temperature [kK]
w0(7) = par.T_in;
lb(7) = par.T_in;
ub(7) = par.T_in;
% V_L = w(8);           % Liquid volume [m^3]
w0(8) = par.V_T;
lb(8) = par.V_T;
ub(8) = par.V_T;
% x_1 = w(9);           % Liquid mole fraction
w0(9) = 1;
lb(9) = 1;
ub(9) = 1;
% y_1 = w(10);          % Vapor mole fraction
w0(10) = 0.5;
lb(10) = 0;
ub(10) = inf;
% H = w(11);            % Enthalpy [MJ]
w0(11) = 1;
lb(11) = -inf;
ub(11) = inf;
% h_L = w(12);          % Liquid molar enthalpy [MJ/kmol]
w0(12) = par.h_in;
lb(12) = par.h_in;
ub(12) = par.h_in;
% h_V = w(13);          % Vapor molar enthalpy [MJ/kmol]
w0(13) = par.h_in;
lb(13) = 0;
ub(13) = inf;
% V_V = w(14);          % Vapor volume [m^3]
w0(14) = 0;
lb(14) = 0;
ub(14) = 0;
% rho_L = w(15);        % Liquid molar density [Mmol/m^3]
w0(15) = 0.5;
lb(15) = 0;
ub(15) = inf;
% M_L = w(16);          % Liquid molar hold-up [kmol]
w0(16) = 1;
lb(16) = 0;
ub(16) = inf;
% K_1 = w(17);          % Vapor-liquid equilibrium coefficient
w0(17) = 1;
lb(17) = 0;
ub(17) = inf;
% Ps_1 = w(18);         % Saturation Pressure [MPa]
w0(18) = 0.1;
lb(18) = 0;
ub(18) = inf;
w0 = w0';
end