%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Parameters for counter current HEX
%******************************************************************

function par = parameters_CC()
%% Literature 
% https://webbook.nist.gov/cgi/cbook.cgi?ID=C67561&Mask=4&Type=ANTOINE&Plot=on
% https://webbook.nist.gov/cgi/cbook.cgi?ID=C7732185&Mask=4&Type=ANTOINE&Plot=on
% http://www.personal.utulsa.edu/~geoffrey-price/Courses/ChE7023/
% HeatCapacity-HeatOfFormation.pdf
%% Parameters
% Antoine Parameters log(p_sat[bar]) = A - B/(T[K]+C)
A = [5.15853 4.6543];
B = [1569.613 1435.264];
C = [-34.846 -64.848];

par.T_in = 0.410;       % Temperature inlet hot side [kK]
par.T_in_2 = 0.300;     % Temperature inlet cold side [kK]
par.F_in = 0.1;         % Inlet flow rate hot side [kmol/s]
par.F_in_2 = 0.1;       % Inlet flow rate cold side [kmol/s]
par.Antoine = [A;B;C];  % Antoine parameters
par.h_vap = [35.210 40.660]; % Heat of vaporization [MJ/kmol]
par.Cp_V = [44.06, 35]; % Vapor Heat Capacity [MJ/kmol*kK]
par.Cp_L = [81.08, 75]; % Liquid Heat Capacity [MJ/kmol*kK]
par.R = 8.314;          % Gas constant [MJ/(kK * kmol)]
par.P_0 = 0.1;          % Outlet Pressure [MPa]
par.V_T = 0.2;          % Total volume [m^3]
par.rho = [0.792/32.04, 1/18.016]; % Liquid molar density[Mmol/m^3]
par.c_V = 1;            % Valve coefficient vapor[kmol/(bar^(-0.5) s)]
par.c_L = 5;            % Valve coefficient liquid [kmol/(bar^(-0.5) s)]
par.z = [1 1];          % Composition inlet [Hot Cold]      
par.C0 = 3*145.0377e-6; % Liquid compressability factor [1/MPa]
par.M = 3;              % Nr of Flash Tanks in series
par.T_ref = 0.29815;    % Reference temperature [kK]
par.UA = 4;             % Heat transfer coefficient times area [MW/kK]

%% Calculation of inlet enthalpy [MJ/kmol] 
% This calculation assumes that the inlet on the hot side is vapor and that
% the cold side is liquid.
par.h_in = par.h_vap(1) + par.Cp_V(1)*(par.T_in-par.T_ref);
par.h_in_2 = par.Cp_L(2)*(par.T_in_2-par.T_ref);
end