%**************************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Parameters for HEX with methanol as inlet in vapor phase
%**************************************************************************

function par = parameters_Methanol()
%https://webbook.nist.gov/cgi/cbook.cgi?ID=C67561&Mask=4&Type=ANTOINE&Plot=on
%https://webbook.nist.gov/cgi/cbook.cgi?ID=C7732185&Mask=4&Type=ANTOINE&Plot=on
%% Parameters
% Antoine Parameters log(p_sat[bar]) = A - B/(T[K]+C)
A = 5.15853;
B = 1569.613;
C = -34.846;
par.T_in = 0.410;       % Inlet Temperature [kK]
par.F_in = 0.1;         % Inlet flow rate hot side [kmol/s]
par.Q = 0;              % Heat transfer [MW]
par.Antoine = [A;B;C];  % Antoine parameters
par.h_vap = 35.210;     % Heat of vaporization [MJ/kmol]
par.Cp_V = 44.06;       % Vapor Heat Capacity [MJ/kmol*kK]
par.Cp_L = 81.08;       % Liquid Heat Capacity [MJ/kmol*kK]
par.R = 8.314;          % Gas constant [MJ/(kK * kmol)]
par.P_0 = 0.1;          % Outlet Pressure [MPa]
par.V_T = 0.2;          % Total volume [m^3]
par.rho = 0.792/32.04;  % Liquid molar density[Mmol/m^3]
par.c_V = 1;            % Valve coefficient vapor[kmol/(bar^(-0.5) s)]
par.c_L = 5;            % Valve coefficient liquid [kmol/(bar^(-0.5) s)]
par.z = 1;              % Inlet composition
par.C0 = 3*145.0377e-6; % Liquid compressability factor [1/MPa]
par.M = 3;              % Nr of Flash Tanks in series
par.T_ref = 0.29815;    % Reference temperature [kK]
%% Calculation of inlet enthalpy [MJ/kmol] 
% This calculation assumes that the inlet  is vapor
par.h_in = par.h_vap(1) + par.Cp_V(1)*(par.T_in-par.T_ref);
end
