%**************************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Parameters for HEX with water as inlet in liquid phase
%**************************************************************************

function par = parameters_water()
%https://webbook.nist.gov/cgi/cbook.cgi?ID=C67561&Mask=4&Type=ANTOINE&Plot=on
%https://webbook.nist.gov/cgi/cbook.cgi?ID=C7732185&Mask=4&Type=ANTOINE&Plot=on
%% Parameters
% Antoine Parameters log(p_sat[bar]) = A - B/(T[K]+C)
A = 4.6543;
B = 1435.264;
C = -64.848;
par.T_in = 0.300;       % Inlet Temperature [kK]
par.F_in = 0.1;         % Inlet flow rate hot side [kmol/s]
par.Q = 0;              % Heat transfer [MW]
par.Antoine = [A;B;C];  % Antoine parameters
par.h_vap = 40.660;     % Heat of vaporization [MJ/kmol]
par.Cp_V =  35;         % Vapor Heat Capacity [MJ/kmol*kK]
par.Cp_L =  75;         % Liquid Heat Capacity [MJ/kmol*kK]
par.R = 8.314;          % Gas constant [MJ/(kK * kmol)]
par.P_0 = 0.1;          % Outlet Pressure [MPa]
par.V_T = 0.2;          % Total volume [m^3]
par.rho = 1/18.016;     % Liquid molar density[Mmol/m^3]
par.c_V = 1;            % Valve coefficient vapor[kmol/(bar^(-0.5) s)]
par.c_L = 5;            % Valve coefficient liquid [kmol/(bar^(-0.5) s)]
par.z = 1;              % Inlet composition
par.C0 = 3*145.0377e-6; % Liquid compressability factor [1/MPa]
par.M = 3;              % Nr of Flash Tanks in series
par.T_ref = 0.29815;    % Reference temperature [kK]
%% Calculation of inlet enthalpy [MJ/kmol] 
% This calculation assumes that the inlet  is liquid
par.h_in = par.Cp_L*(par.T_in-par.T_ref);
end