%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: This function produces plots from results obtained by
%               simulating a two component  HEX.
% @input:		t = time, w = system variables, Q = heat transfer,
%******************************************************************

function plotHEX(t,w,Q)
M = length(w(:,1))/23;
M_1 = w(1:M,:);
M_2 = w(M+1:2*M,:);
U = w(2*M+1:3*M,:);
F_V = w(3*M+1:4*M,:);
F_L = w(4*M+1:5*M,:);
M_V = w(5*M+1:6*M,:);
P = w(6*M+1:7*M,:);
T = w(7*M+1:8*M,:);
V_L = w(8*M+1:9*M,:);
x_1 = w(9*M+1:10*M,:);
x_2 = w(10*M+1:11*M,:);
y_1 = w(11*M+1:12*M,:);
y_2 = w(12*M+1:13*M,:);
H = w(13*M+1:14*M,:);
h_L = w(14*M+1:15*M,:);
h_V = w(15*M+1:16*M,:);
V_V = w(16*M+1:17*M,:);
rho_L = w(17*M+1:18*M,:);
M_L = w(18*M+1:19*M,:);
k_1 = w(19*M+1:20*M,:);
k_2 = w(20*M+1:21*M,:);
Ps_1 = w(21*M+1:22*M,:);
Ps_2 = w(22*M+1:23*M,:);

markerSet = {'-','--',':','-','--',':'};
ColorSet = [0 0.4470 0.7410;0.8500 0.3250 0.0980];
set(0,'defaulttextInterpreter','latex','DefaultAxesFontName',...
 'Times New Roman','DefaultTextFontname', 'Times New Roman',...
 'DefaultLineLineWidth',6)
%% Molar hold-up Comp1
figure(1)
hold on
p = plot(t, [M_1',M_2']);
for i = 1:2*M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
ax = gca;
plot([5,5],[0,1.5],'k--',[100,100],[0,1.5],'k--','lineWidth',2)
ylim([0,1.5])
ax.XGrid = 'off';
ax.YGrid = 'on';
legend('M_1^1','M_1^2','M_1^3','M_2^1','M_2^2','M_2^3','Location',...
    'NorthEastOutside')
xlabel('t [s]','FontSize', 50)
ylabel('Molar hold-up [kmol]', 'interpreter','latex')
set(gca,'FontSize',50);

%% Flows
figure(2)
hold on
p = plot(t, [F_V',F_L']);
for i = 1:2*M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,1.5],'k--',[100,100],[0,1.5],'k--','lineWidth',2)
ylim([0,0.11])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Outlet Flow [kmol/s]')
legend('F_V^1','F_V^2','F_V^3','F_L^1','F_L^2','F_L^3','Location',...
    'NorthEastOutside')
set(gca,'FontSize',50);

%% Phase molar hold-up
figure(3)
hold on
yyaxis left
plot(t, M_V);
ylim([0,3e-3])
ylabel('Molar hold-up [kmol]', 'interpreter','latex')
yyaxis right
plot(t, M_L);
plot([5,5],[0,4],'k--',[100,100],[0,4],'k--','lineWidth',2)
ylim([0,3])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Molar hold-up [kmol]', 'interpreter','latex')
legend('M_V^1','M_V^2','M_V^3','M_L^1','M_L^2','M_L^3','Location',...
    'NorthEastOutside')
set(gca,'FontSize',50);
%% Pressure
figure(4)
hold on
p = plot(t, P*10);
for i = 1:M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,4],'k--',[100,100],[0,4],'k--','lineWidth',2)
ylim([0.8,1.2])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Pressure, p[bar]', 'interpreter','latex')
legend('p^1','p^2','p^3','Location','NorthEastOutside')
set(gca,'FontSize',50);

%% Temperature
figure(5)
hold on
p = plot(t, T*1000);
for i = 1:M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,500],'k--',[100,100],[0,500],'k--','lineWidth',2)
ylim([320,420])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Temperature, T[K]', 'interpreter','latex')
legend('T^1','T^2','T^3','Location','NorthEastOutside')
set(gca,'FontSize',50);

%% Composition Vapor
figure(6)
hold on
p = plot(t, [y_1', y_2']);
for i = 1:2*M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,4],'k--',[100,100],[0,4],'k--','lineWidth',2)
ylim([0,1])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Mole fraction')
legend('y_1^1','y_1^2','y_1^3','y_2^1','y_2^2','y_2^3','Location',...
    'NorthEastOutside')
set(gca,'FontSize',50);

%% Composition Vapor
figure(7)
hold on
p = plot(t, [x_1', x_2']);
for i = 1:2*M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,4],'k--',[100,100],[0,4],'k--','lineWidth',2)
ylim([0,1])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Mole fraction')
legend('x_1^1','x_1^2','x_1^3','x_2^1','x_2^2','x_2^3','Location',...
    'NorthEastOutside')
set(gca,'FontSize',50);

%% Volume
figure(8)
hold on
p = plot(t, [V_V', V_L']);
for i = 1:2*M
    if i <= M
        p(i).Color = ColorSet(1,:);
    else
        p(i).Color = ColorSet(2,:);
    end
    p(i).LineStyle = markerSet{i};
end
plot([5,5],[0,4],'k--',[100,100],[0,4],'k--','lineWidth',2)
ylim([0,0.2/3])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Volume [$m^3$]')
legend('V_V^1','V_V^2','V_V^3','V_L^1','V_L^2','V_L^3','Location',...
    'NorthEastOutside')
set(gca,'FontSize',50);

figure(9)
hold on
plot(t, Q);
plot([5,5],[-5,4],'k--',[100,100],[-5,4],'k--','lineWidth',2)
ylim([-4,0])
ax = gca;
ax.XGrid = 'off';
ax.YGrid = 'on';
xlabel('t [s]','FontSize', 50)
ylabel('Heat, Q [MW]', 'interpreter','latex')
set(gca,'FontSize',50);

end