%******************************************************************
% @author: Marius Reed
% @organization: Process Systems Engineering, NTNU
% @since: 03-12-2018
% @requires: MATLAB R2017b (not tested in other releases)
% @description: Implicit Euler integrator for two component flash tank
% @input: w0 = initial conditions, data = parameters, dt = time step,
% tspan = [t_start, t_end]
% @output: t = time vector, w = System variables matrix, Q = heat transfer
%******************************************************************

function [t,w,Q] = implicitSolver(w0,data,dt,tspan)
% Solver settings
options_fsolve = optimoptions(@fsolve,'Display','off',...
     'MaxIterations',1e3,'MaxFunEvals',1e10,...
     'stepTolerance',1e-13,'FunctionTolerance',1e-13,...
     'specifyObjectiveGradient', true,...
     'OptimalityTolerance',1e-13, 'Algorithm','levenberg-marquardt');
% Preallocating memory and setting the first value equal to initial values
t = tspan(1):dt:tspan(2);
w = zeros(length(w0),length(t));
Q = zeros(1,length(t));
w(:,1) = w0;
Q(1) = data.par.Q;

% Solving the flash model and doing time steps integrations
for i = 2:length(t)
    disp(t(i));
    w0 = w(:,i-1);
    dynVar = w(1:3,i-1);
    w(:,i) = fsolve(@(w) Flash_implicit(t(i),w,data,dynVar,dt)...
        ,w0,options_fsolve);
    [~,~,Q(i)] = Flash(t(i),w(:,i),data);
end
end